@@ -1,16 +1,4 @@
-### S3 tool function except print() and cat() see "spmd_tool.r".
-
-comm.any <- function(x, na.rm = FALSE, comm = .SPMD.CT$comm){
-  ret <- spmd.allgather.integer(any(x, na.rm = na.rm),
-                                integer(comm.size(comm)), comm = comm)
-  any(ret, na.rm = na.rm)
-} # End of comm.any().
-
-comm.all <- function(x, na.rm = FALSE, comm = .SPMD.CT$comm){
-  ret <- spmd.allgather.integer(all(x, na.rm = na.rm),
-                                integer(comm.size(comm)), comm = comm)
-  all(ret, na.rm = na.rm)
-} # End of comm.all().
+### S3 tool function.
 
 comm.timer <- function(timed, comm = .SPMD.CT$comm){
   ltime <- system.time(timed)[3]
